@@ -171,9 +171,9 @@ class _TestBase:
         self.assertEqual(calls, ['a'])
 
     def test_call_at(self):
-        if os.environ.get('TRAVIS_OS_NAME') == 'osx':
-            # Time seems to be really unpredictable on Travis' macOS.
-            raise unittest.SkipTest('time is not monotonic on Travis/macOS')
+        if os.environ.get('TRAVIS_OS_NAME'):
+            # Time seems to be really unpredictable on Travis.
+            raise unittest.SkipTest('time is not monotonic on Travis')
 
         i = 0
 
